@@ -27,68 +27,74 @@ For more control you can use one of the following Task classes
 and use schedule_task or schedule_task_abs:
 
     IntervalTask    ThreadedIntervalTask    ForkedIntervalTask
-    SingleTask      ThreadedSingleTask      ForkedSingleTask 
+    SingleTask      ThreadedSingleTask      ForkedSingleTask
     WeekdayTask     ThreadedWeekdayTask     ForkedWeekdayTask
     MonthdayTask    ThreadedMonthdayTask    ForkedMonthdayTask
+    CronLikeTask    ThreadedCronLikeTask    ForkedCronLikeTask
 
-Kronos is the Greek God of Time.
+Kronos is the Greek god of time. Kronos scheduler (c) by Iremen de Jong.
+
+This module is based on the Kronos scheduler by Irmen de Jong, but has been
+modified to better fit within TurboGears. Vince Spicer and Mathieu Bridon have
+contributed some additions and improvements such as cron-like tasks. Some fixes
+have been made to make it work on Python 2.6 (adaptations sched module changes).
 
-Kronos scheduler (c) Irmen de Jong.
 This version has been extracted from the Turbogears source repository
-and slightly changed to be completely stand-alone again. Also some fixes
-have been made to make it work on Python 2.6 (sched module changes).
-The version in Turbogears is based on the original stand-alone Kronos.
+and slightly changed to be completely stand-alone again.
+
 This is open-source software, released under the MIT Software License:
 http://www.opensource.org/licenses/mit-license.php
 
 """
 
-__version__ = "2.0"
+__version__ = '2.0'
 
 __all__ = [
-    "DayTaskRescheduler",
-    "ForkedIntervalTask",
-    "ForkedMonthdayTask",
-    "ForkedScheduler",
-    "ForkedSingleTask",
-    "ForkedTaskMixin",
-    "ForkedWeekdayTask",
-    "ForkedCronLikeTask",
-    "IntervalTask",
-    "MonthdayTask",
-    "CronLikeTask",
-    "Scheduler",
-    "SingleTask",
-    "Task",
-    "ThreadedIntervalTask",
-    "ThreadedMonthdayTask",
-    "ThreadedScheduler",
-    "ThreadedSingleTask",
-    "ThreadedTaskMixin",
-    "ThreadedWeekdayTask",
-    "ThreadedCronLikeTask",
-    "WeekdayTask",
-    "add_interval_task",
-    "add_monthday_task",
-    "add_single_task",
-    "add_weekday_task",
-    "add_cron_like_task",
-    "cancel",
-    "method",
+    'DayTaskRescheduler',
+    'ForkedIntervalTask',
+    'ForkedMonthdayTask',
+    'ForkedScheduler',
+    'ForkedSingleTask',
+    'ForkedTaskMixin',
+    'ForkedWeekdayTask',
+    'ForkedCronLikeTask',
+    'IntervalTask',
+    'MonthdayTask',
+    'CronLikeTask',
+    'Scheduler',
+    'SingleTask',
+    'Task',
+    'ThreadedIntervalTask',
+    'ThreadedMonthdayTask',
+    'ThreadedScheduler',
+    'ThreadedSingleTask',
+    'ThreadedTaskMixin',
+    'ThreadedWeekdayTask',
+    'ThreadedCronLikeTask',
+    'WeekdayTask',
+    'add_interval_task',
+    'add_monthday_task',
+    'add_single_task',
+    'add_weekday_task',
+    'add_cron_like_task',
+    'cancel',
+    'method',
 ]
 
 import os
 import sys
 import sched
+import datetime
 import time
-import traceback
+import logging
 import weakref
 
-import logging
-log = logging.getLogger(__name__)
+try:
+    from dateutil import rrule
+except ImportError:
+    rrule = None
 
-import datetime
-from dateutil.rrule import rrule, SECONDLY
+log = logging.getLogger(__name__)
 
 # bounds for each field of the cron-like syntax
 MINUTE_BOUNDS = (0, 59)
@@ -98,18 +104,22 @@ MONTH_BOUNDS = (1, 12)
 DOW_BOUNDS = (0, 7)
 
 # some fields of the cron-like syntax can be specified as names
-MONTH_MAPPING = {'jan': 1, 'feb': 2, 'mar': 3, 'apr': 4, 'may': 5, 'jun': 6,
-        'jul': 7, 'aug': 8, 'sep': 9, 'oct': 10, 'nov': 11, 'dec': 12}
-DOW_MAPPING = {'sun': 0, 'mon': 1, 'tue': 2, 'wed': 3, 'thu': 4, 'fri': 5,
-        'sat': 6}
+MONTH_MAPPING = {
+    'jan': 1, 'feb': 2, 'mar': 3, 'apr': 4, 'may': 5, 'jun': 6,
+    'jul': 7, 'aug': 8, 'sep': 9, 'oct': 10, 'nov': 11, 'dec': 12}
+DOW_MAPPING = {
+    'sun': 0, 'mon': 1, 'tue': 2, 'wed': 3, 'thu': 4, 'fri': 5, 'sat': 6}
 
 
-class method:
-    sequential = "sequential"
-    forked = "forked"
-    threaded = "threaded"
+class method(object):
+    """Enumerator class for the scheduler methods."""
 
-class Scheduler:
+    sequential = 'sequential'
+    forked = 'forked'
+    threaded = 'threaded'
+
+
+class Scheduler(object):
     """The Scheduler itself."""
 
     def __init__(self):
@@ -118,18 +128,20 @@ class Scheduler:
         self.tasks = dict()
 
     def __delayfunc(self, delay):
-        """ 
-        This delay function is basically a time.sleep() that is
-        divided up, so that we can check the self.running flag while delaying.
-        there is an additional check in here to ensure that the top item of
-        the queue hasn't changed 
+        """The delay function for the sched.scheduler.
+
+        This delay function is basically a time.sleep() that is divided up,
+        so that we can check the self.running flag while delaying.
+        There is an additional check in here to ensure that the top item of
+        the queue hasn't changed.
+
         """
-        if delay < 10:
+        period = 5
+        if delay < period:
             time.sleep(delay)
         else:
             toptime = self._getqueuetoptime()
             endtime = time.time() + delay
-            period = 5
             stoptime = endtime - period
             while self.running and stoptime > time.time():
                 self._acquire_lock()
@@ -138,7 +150,6 @@ class Scheduler:
                         break
                 finally:
                     self._release_lock()
-
                 time.sleep(period)
             if not self.running or self._getqueuetoptime() != toptime:
                 return
@@ -155,8 +166,8 @@ class Scheduler:
     def add_interval_task(self, action, taskname, initialdelay, interval,
             processmethod, args, kw):
         """Add a new Interval Task to the schedule.
-        
-        A very short initialdelay or one of zero cannot be honored, you will 
+
+        A very short initialdelay or one of zero cannot be honored, you will
         see a slight delay before the task is first executed. This is because
         the scheduler needs to pick it up in its loop.
 
@@ -179,20 +190,22 @@ class Scheduler:
         if self.running:
             self._acquire_lock()
             try:
-                if self.tasks.has_key(taskname):
-                    raise ValueError("A task with the name %s already exists" % taskname)
+                if taskname in self.tasks:
+                    raise ValueError(
+                        "A task with the name %s already exists" % taskname)
             finally:
                 self._release_lock()
         else:
-            if self.tasks.has_key(taskname):
-                raise ValueError("A task with the name %s already exists" % taskname)
+            if taskname in self.tasks:
+                raise ValueError(
+                    "A task with the name %s already exists" % taskname)
         task = TaskClass(taskname, interval, action, args, kw)
         self.schedule_task(task, initialdelay)
         return task
 
     def add_single_task(self, action, taskname, initialdelay, processmethod,
             args, kw):
-        """ Add a new task to the scheduler that will only be executed once. """
+        """Add a new task to the scheduler that will only be executed once."""
         if initialdelay < 0:
             raise ValueError("Delay must be >0")
         # Select the correct SingleTask class. Not all types may be available!
@@ -211,20 +224,22 @@ class Scheduler:
         if self.running:
             self._acquire_lock()
             try:
-                if self.tasks.has_key(taskname):
-                    raise ValueError("A task with the name %s already exists" % taskname)
+                if taskname in self.tasks:
+                    raise ValueError(
+                        "A task with the name %s already exists" % taskname)
             finally:
                 self._release_lock()
         else:
-            if self.tasks.has_key(taskname):
-                raise ValueError("A task with the name %s already exists" % taskname)
+            if taskname in self.tasks:
+                raise ValueError(
+                    "A task with the name %s already exists" % taskname)
         task = TaskClass(taskname, action, args, kw)
         self.schedule_task(task, initialdelay)
         return task
 
     def add_daytime_task(self, action, taskname, weekdays, monthdays, timeonday,
             processmethod, args, kw):
-        """ Add a new Day Task (Weekday or Monthday) to the schedule. """
+        """Add a new Day Task (Weekday or Monthday) to the schedule."""
         if weekdays and monthdays:
             raise ValueError("You can only specify weekdays or monthdays, "
                 "not both")
@@ -246,13 +261,15 @@ class Scheduler:
             if self.running:
                 self._acquire_lock()
                 try:
-                    if self.tasks.has_key(taskname):
-                        raise ValueError("A task with the name %s already exists" % taskname)
+                    if taskname in self.tasks:
+                        raise ValueError(
+                            "A task with the name %s already exists" % taskname)
                 finally:
                     self._release_lock()
             else:
-                if self.tasks.has_key(taskname):
-                    raise ValueError("A task with the name %s already exists" % taskname)
+                if taskname in self.tasks:
+                    raise ValueError(
+                        "A task with the name %s already exists" % taskname)
             task = TaskClass(taskname, weekdays, timeonday, action, args, kw)
         if monthdays:
             # Select the correct MonthdayTask class.
@@ -268,13 +285,15 @@ class Scheduler:
             if self.running:
                 self._acquire_lock()
                 try:
-                    if self.tasks.has_key(taskname):
-                        raise ValueError("A task with the name %s already exists" % taskname)
+                    if taskname in self.tasks:
+                        raise ValueError(
+                            "A task with the name %s already exists" % taskname)
                 finally:
                     self._release_lock()
             else:
-                if self.tasks.has_key(taskname):
-                    raise ValueError("A task with the name %s already exists" % taskname)
+                if taskname in self.tasks:
+                    raise ValueError(
+                        "A task with the name %s already exists" % taskname)
             task = TaskClass(taskname, monthdays, timeonday, action, args, kw)
         firsttime = task.get_schedule_time(True)
         self.schedule_task_abs(task, firsttime)
@@ -282,7 +301,7 @@ class Scheduler:
 
     def add_cron_like_task(self, action, taskname, cron_str,
             processmethod, args, kw):
-        """ Add a new Cron-like Task to the schedule. """
+        """Add a new Cron-like Task to the schedule."""
         if not args:
             args = []
         if not kw:
@@ -298,29 +317,32 @@ class Scheduler:
         if self.running:
             self._acquire_lock()
             try:
-                if self.tasks.has_key(taskname):
-                    raise ValueError("A task with the name %s already exists" % taskname)
+                if taskname in self.tasks:
+                    raise ValueError(
+                        "A task with the name %s already exists" % taskname)
             finally:
                 self._release_lock()
         else:
-            if self.tasks.has_key(taskname):
-                raise ValueError("A task with the name %s already exists" % taskname)
+            if taskname in self.tasks:
+                raise ValueError(
+                    "A task with the name %s already exists" % taskname)
         task = TaskClass(taskname, action, cron_str, args, kw)
         firsttime = task.get_schedule_time()
         self.schedule_task_abs(task, firsttime)
         return task
 
     def schedule_task(self, task, delay):
-        """
-        Add a new task to the scheduler with the given delay (seconds).
+        """Add a new task to the scheduler with the given delay (seconds).
+
         Low-level method for internal use.
+
         """
         if self.running:
             # lock the sched queue, if needed
             self._acquire_lock()
             try:
-                task.event = self.sched.enter(delay, 0, task,
-                            (weakref.ref(self),) )
+                task.event = self.sched.enter(
+                    delay, 0, task, (weakref.ref(self),))
                 if task.name:
                     self.tasks[task.name] = task
                 else:
@@ -328,24 +350,25 @@ class Scheduler:
             finally:
                 self._release_lock()
         else:
-            task.event = self.sched.enter(delay, 0, task,
-                        (weakref.ref(self),) )
+            task.event = self.sched.enter(
+                delay, 0, task, (weakref.ref(self),))
             if task.name:
                 self.tasks[task.name] = task
             else:
                 log.debug("task %s doesn't have a name" % task)
 
     def schedule_task_abs(self, task, abstime):
-        """
-        Add a new task to the scheduler for the given absolute time value.
+        """Add a new task to the scheduler for the given absolute time value.
+
         Low-level method for internal use.
+
         """
         if self.running:
             # lock the sched queue, if needed
             self._acquire_lock()
             try:
-                task.event = self.sched.enterabs(abstime, 0, task,
-                                    (weakref.ref(self),) )
+                task.event = self.sched.enterabs(
+                    abstime, 0, task, (weakref.ref(self),))
                 if task.name:
                     self.tasks[task.name] = task
                 else:
@@ -353,19 +376,19 @@ class Scheduler:
             finally:
                 self._release_lock()
         else:
-            task.event = self.sched.enterabs(abstime, 0, task,
-                                (weakref.ref(self),) )
+            task.event = self.sched.enterabs(
+                abstime, 0, task, (weakref.ref(self),))
             if task.name:
                 self.tasks[task.name] = task
             else:
                 log.debug("task %s doesn't have a name" % task)
 
     def start(self):
-        """ Start the scheduler. """
+        """Start the scheduler."""
         self._run()
 
     def stop(self):
-        """ Remove all pending tasks and stop the Scheduler. """
+        """Remove all pending tasks and stop the scheduler."""
         self.running = False
         self._clearschedqueue()
 
@@ -375,32 +398,32 @@ class Scheduler:
             self._acquire_lock()
             try:
                 self.sched.cancel(task.event)
-                if task.name and self.tasks.has_key(task.name):
+                if task.name and task.name in self.tasks:
                     del self.tasks[task.name]
             finally:
                 self._release_lock()
         else:
             self.sched.cancel(task.event)
-            if task.name and self.tasks.has_key(task.name):
+            if task.name and task.name in self.tasks:
                 del self.tasks[task.name]
 
     def rename(self, taskname, newname):
-       """ Rename a scheduled task """
+        """Rename a scheduled task."""
+        if taskname and taskname in self.tasks:
+            task = self.tasks[taskname]
+            del self.tasks[taskname]
+            task.name = newname
+            self.tasks[newname] = task
 
-       if taskname and self.tasks.has_key(taskname):
-           task = self.tasks[taskname]
-           del self.tasks[taskname]
-           self.tasks[newname] = task
-
-    if sys.version_info >= (2,6):
-        # code for sched module of python 2.6+
+    if sys.version_info >= (2, 6):
+        # code for sched module of Python >= 2.6
         def _getqueuetoptime(self):
             if len(self.sched._queue):
                 return self.sched._queue[0].time
         def _clearschedqueue(self):
             self.sched._queue[:] = []
     else:
-        # code for sched module of python 2.5 and older
+        # code for sched module of Python < 2.6
         def _getqueuetoptime(self):
             if len(self.sched.queue) and len(self.sched.queue[0]):
                 return self.sched.queue[0][0]
@@ -408,23 +431,25 @@ class Scheduler:
             self.sched.queue[:] = []
 
     def _run(self):
-        """ Low-level run method to do the actual scheduling loop. """
+        """Low-level run method to do the actual scheduling loop."""
+        period = 0 # increase only slowly
         while self.running:
             try:
                 self.sched.run()
-            except Exception, err:
+            except Exception:
                 log.error("ERROR DURING SCHEDULER EXECUTION", exc_info=1)
-                log.error("-" * 20)
             # queue is empty; sleep a short while before checking again
             if self.running:
-                time.sleep(5)
+                if period < 5:
+                    period += 0.25
+                time.sleep(period)
 
 
-class Task:
-    """ Abstract base class of all scheduler tasks """
+class Task(object):
+    """Abstract base class of all scheduler tasks"""
 
     def __init__(self, name, action, args, kw):
-        """This is an abstract class!"""
+        """This is an abstract class."""
         self.name = name
         self.action = action
         self.args = args
@@ -434,12 +459,12 @@ class Task:
         """Execute the task action in the scheduler's thread."""
         try:
             self.execute()
-        except Exception, err:
-            self.handle_exception(err)
+        except Exception:
+            self.handle_exception()
         self.reschedule(schedulerref())
 
     def reschedule(self, scheduler):
-        """ This method should be defined in one of the sub classes! """
+        """This method should be defined in one of the sub classes."""
         raise NotImplementedError("You're using the abstract base class 'Task',"
             " use a concrete class instead")
 
@@ -447,21 +472,20 @@ class Task:
         """Execute the actual task."""
         self.action(*self.args, **self.kw)
 
-    def handle_exception(self, exc):
-        """ Handle any exception that occured during task execution. """
+    def handle_exception(self):
+        """Handle any exception that occurred during task execution. """
         log.error("ERROR DURING TASK EXECUTION", exc_info=1)
-        log.error("-" * 20)
 
 
 class SingleTask(Task):
-    """ A task that only runs once. """
+    """A task that only runs once."""
 
     def reschedule(self, scheduler):
         pass
 
 
 class IntervalTask(Task):
-    """ A repeated task that occurs at certain intervals (in seconds) ."""
+    """A repeated task that occurs at certain intervals (in seconds)."""
 
     def __init__(self, name, interval, action, args=None, kw=None):
         Task.__init__(self, name, action, args, kw)
@@ -473,7 +497,7 @@ class IntervalTask(Task):
             scheduler.schedule_task(self, self.interval)
 
 
-class DayTaskRescheduler:
+class DayTaskRescheduler(object):
     """A mixin class that contains the reschedule logic for the DayTasks."""
 
     def __init__(self, timeonday):
@@ -498,7 +522,7 @@ class DayTaskRescheduler:
 
     def reschedule(self, scheduler):
         """Reschedule this task according to the daytime for the task.
-        
+
         The task is scheduled for tomorrow, for the given daytime.
 
         """
@@ -510,9 +534,11 @@ class DayTaskRescheduler:
 
 
 class WeekdayTask(DayTaskRescheduler, Task):
-    """A task that is called at specific days in a week (1-7), at a fixed time
+    """A task that is run on a given weekday.
+
+    The task is called at specific days in a week (1-7), at a fixed time
     on the day.
-    
+
     """
 
     def __init__(self, name, weekdays, timeonday, action, args=None, kw=None):
@@ -534,9 +560,11 @@ class WeekdayTask(DayTaskRescheduler, Task):
 
 
 class MonthdayTask(DayTaskRescheduler, Task):
-    """A task that is called at specific days in a month (1-31), at a fixed 
+    """A task that is run on a given day every month.
+
+    The task is called at specific days in a month (1-31), at a fixed
     time on the day.
-    
+
     """
 
     def __init__(self, name, monthdays, timeonday, action, args=None, kw=None):
@@ -557,11 +585,58 @@ class MonthdayTask(DayTaskRescheduler, Task):
 
 
 class CronLikeTask(Task):
-    """A class that is scheduled with a cron-like syntax.
+    """A task that is scheduled based on a cron-like string.
+
+    A cron string is composed of **five** time and date fields,
+    **separated by spaces**.
+
+    Note: Tasks are executed when **all** the time and date fields match
+    the current time. This is an important difference with the UNIX cron.
+
+    The time and date fields are:
+
+    =============  ==================================
+        field                allowed values
+    =============  ==================================
+    minute         0-59
+    hour           0-23
+    day of month   1-31
+    month          1-12 (or names, see below)
+    day of week    0-7 (0 or 7 is Sun, or use names)
+    =============  ==================================
+
+    A field may be an **asterisk** (``*``), which always stands for
+    *first-last*.
+
+    **Ranges** of numbers are allowed. Ranges are two numbers separated with
+    a hyphen. The specified range is inclusive. For example, ``8-11`` for
+    an "hours" entry specifies *execution at hours 8, 9, 10 and 11*.
+
+    **Lists** are allowed. A list is a set of numbers (or ranges) separated
+    by commas. Examples: ``1,2,5,9``, ``0-4,8-12``.
+
+    **Step values** can be used in conjunction with ranges. Following a
+    range with  ``/<number>`` specifies skips of the number's value through
+    the range. For example,``0-23/2`` can be used in the "hours" field to
+    specify task execution *every other hour* (the alternative in the V7
+    standard is ``0,2,4,6,8,10,12,14,16,18,20,22``). Steps are also
+    permitted after an asterisk, so if you want to say *every two hours*,
+    just use ``*/2``.
+
+    **Names** can also be used for the "month" and "day of week" fields. Use
+    the first three letters of the particular day or month (case doesn't
+    matter). Ranges of mixed names and integer are not permitted.
+
     """
+
     def __init__(self, name, action, cron_str, args=None, kw=None):
+        """Initialize the task."""
         Task.__init__(self, name, action, args, kw)
 
+        if not rrule:
+            raise ImportError("The dateutil package must be installed"
+                " if you want to use cron-like tasks.")
+
         self.cron_str = cron_str
         try:
             min_str, hour_str, dom_str, month_str, dow_str = cron_str.split()
@@ -571,7 +646,8 @@ class CronLikeTask(Task):
         self.minutes = self.__process_str(min_str, MINUTE_BOUNDS)
         self.hours = self.__process_str(hour_str, HOUR_BOUNDS)
         self.doms = self.__process_str(dom_str, DOM_BOUNDS)
-        self.months = self.__process_str(month_str, MONTH_BOUNDS, mapping=MONTH_MAPPING)
+        self.months = self.__process_str(month_str, MONTH_BOUNDS,
+            mapping=MONTH_MAPPING)
 
         # dows are somewhat special:
         #   * Cron accepts both 0 and 7 for Sunday
@@ -580,16 +656,13 @@ class CronLikeTask(Task):
         #     => we deal with that by substracting 1
         #   * (SUN - 1) % 7 = (0 - 1) % 7 = 6
         #     => we need to sort the list
-        self.dows = list(set([ (dow - 1) % 7 \
+        self.dows = list(set([ (dow - 1) % 7
                 for dow in self.__process_str(dow_str,
                         DOW_BOUNDS, mapping=DOW_MAPPING) ]))
         self.dows.sort()
 
     def __process_str(self, time_str, bounds, mapping=None):
-        """Transforms a field of the cron-like string into a list
-
-        Note: specifying a range as a mix of integers and names
-              (months and dows) is NOT supported
+        """Transforms a field of the cron-like string into a list.
 
         @param time_str: a field in the cron-like string
         @type time_str: string
@@ -599,6 +672,7 @@ class CronLikeTask(Task):
 
         @param mapping: the mapping between names and integer values
         @type mapping: dict
+
         """
         freq = 1
         if '/' in time_str:
@@ -615,12 +689,12 @@ class CronLikeTask(Task):
         result = list()
 
         for item in time_str.split(','):
-            if not '-' in item:
+            if '-' not in item:
                 # ex: time_str = "1,4,23"
                 try:
                     time = int(item)
                 except:
-                    if mapping and mapping.has_key(item.lower()):
+                    if mapping and item.lower() in mapping:
                         time = mapping[item.lower()]
                     else:
                         raise ValueError("Invalid value: '%s'" % time_str)
@@ -642,8 +716,8 @@ class CronLikeTask(Task):
                     time_low = int(interval_low)
                     time_high = int(interval_high)
                 except:
-                    if mapping and mapping.has_key(interval_low.lower()) \
-                            and mapping.has_key(interval_high.lower()):
+                    if (mapping and interval_low.lower() in mapping
+                            and interval_high.lower() in mapping):
                         # in some cases names can be used (months or dows)
                         time_low = mapping[interval_low.lower()]
                         time_high = mapping[interval_high.lower()]
@@ -659,8 +733,7 @@ class CronLikeTask(Task):
         return result[::freq]
 
     def get_schedule_time(self):
-        """Determine the next execution time of the task.
-        """
+        """Determine the next execution time of the task."""
         now = datetime.datetime.now()
 
         # rrule will return `now` as the next execution time if `now` fills the
@@ -669,17 +742,17 @@ class CronLikeTask(Task):
         # That only happens when `now.second == 0` (which is always the case
         # after the first execution as cron doesn't handle anything below the
         # minute), so let's add one second to `now`, just to be sure
-        now = now + datetime.timedelta(seconds=1)
+        now += datetime.timedelta(seconds=1)
 
-        next = list(rrule(SECONDLY, count=1, bysecond=0, byminute=self.minutes,
-                byhour=self.hours, bymonthday=self.doms, bymonth=self.months,
-                byweekday=self.dows, dtstart=now)[0].timetuple())
+        next_time = list(rrule.rrule(rrule.SECONDLY, count=1, bysecond=0,
+            byminute=self.minutes, byhour=self.hours,
+            bymonthday=self.doms, bymonth=self.months, byweekday=self.dows,
+            dtstart=now)[0].timetuple())
 
-        return time.mktime(next)
+        return time.mktime(next_time)
 
     def reschedule(self, scheduler):
-        """Reschedule this task according to its cron-like string.
-        """
+        """Reschedule this task according to its cron-like string."""
         if scheduler.running:
             abstime = self.get_schedule_time()
             scheduler.schedule_task_abs(self, abstime)
@@ -702,7 +775,7 @@ try:
             self.thread = threading.Thread(target=self._run)
             self.thread.setDaemon(True)
             self.thread.start()
-            
+
         def stop(self):
             """Stop the scheduler and wait for the thread to finish."""
             Scheduler.stop(self)
@@ -714,13 +787,13 @@ try:
         def _acquire_lock(self):
             """Lock the thread's task queue."""
             self._lock.acquire()
-            
+
         def _release_lock(self):
-            """Release the lock on th ethread's task queue."""
+            """Release the lock on the thread's task queue."""
             self._lock.release()
 
 
-    class ThreadedTaskMixin:
+    class ThreadedTaskMixin(object):
         """A mixin class to make a Task execute in a separate thread."""
 
         def __call__(self, schedulerref):
@@ -729,21 +802,21 @@ try:
             self.reschedule(schedulerref())
 
         def threadedcall(self):
-            """ 
+            """
             This method is run within its own thread, so we have to
             do the execute() call and exception handling here.
             """
             try:
                 self.execute()
-            except Exception, err:
-                self.handle_exception(err)
+            except Exception:
+                self.handle_exception()
 
     class ThreadedIntervalTask(ThreadedTaskMixin, IntervalTask):
         """Interval Task that executes in its own thread."""
         pass
 
     class ThreadedSingleTask(ThreadedTaskMixin, SingleTask):
-        """Single Task that executes in its own thread.""" 
+        """Single Task that executes in its own thread."""
         pass
 
     class ThreadedWeekdayTask(ThreadedTaskMixin, WeekdayTask):
@@ -763,14 +836,14 @@ except ImportError:
     pass
 
 
-if hasattr(os, "fork"):
+if hasattr(os, 'fork'):
     import signal
 
     class ForkedScheduler(Scheduler):
         """A Scheduler that runs in its own forked process."""
 
         def __del__(self):
-            if hasattr(self, "childpid"):
+            if hasattr(self, 'childpid'):
                 os.kill(self.childpid, signal.SIGKILL)
 
         def start(self):
@@ -796,7 +869,7 @@ if hasattr(os, "fork"):
             Scheduler.stop(self)
 
 
-    class ForkedTaskMixin:
+    class ForkedTaskMixin(object):
         """A mixin class to make a Task execute in a separate process."""
 
         def __call__(self, schedulerref):
@@ -806,8 +879,8 @@ if hasattr(os, "fork"):
                 # we are the child
                 try:
                     self.execute()
-                except Exception, err:
-                    self.handle_exception(err)
+                except Exception:
+                    self.handle_exception()
                 os._exit(0)
             else:
                 # we are the parent
@@ -834,19 +907,22 @@ if hasattr(os, "fork"):
         """Cron-like Task that executes in its own process."""
         pass
 
+
 if __name__ == "__main__":
+    """Simple test/demo of the scheduler."""
     log.setLevel(logging.DEBUG)
     ch = logging.StreamHandler()
     ch.setLevel(logging.DEBUG)
     log.addHandler(ch)
 
     def testaction(arg):
-        log.warn(">>>TASK %s sleeping 3 seconds", arg)
+        log.warn(">>> TASK %s sleeping 3 seconds", arg)
         time.sleep(3)
-        log.warn("<<<END_TASK %s", arg)
+        log.warn("<<< END_TASK %s", arg)
 
     s = ThreadedScheduler()
-    s.add_interval_task( testaction, "test action 1", 0, 4, method.threaded, ["task 1"], None )
+    s.add_interval_task( testaction, "test action 1", 0, 4,
+        method.threaded, ["task 1"], None )
     s.start()
 
     log.info("Scheduler started, waiting 15 sec....")
@@ -856,5 +932,3 @@ if __name__ == "__main__":
     s.stop()
 
     log.info("EXITING")
-
-
